@@ -7,13 +7,15 @@ use strict;
 use warnings;
 
 use Moose::Exporter;
-use MooseX::App::Exporter qw(app_base option command_short_description command_long_description);
+use MooseX::App::Exporter qw(app_base app_fuzzy option command_short_description command_long_description);
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Message::Envelope;
 use Scalar::Util qw(blessed);
 
+our $VERSION = '1.11';
+
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
-    with_meta           => [ 'app_base', 'option', 'command_short_description', 'command_long_description' ],
+    with_meta           => [ 'app_base', 'app_fuzzy', 'option', 'command_short_description', 'command_long_description' ],
     also                => [ 'Moose' ],
     as_is               => [ 'new_with_options' ],
     install             => [ 'unimport', 'init_meta' ],
@@ -53,6 +55,8 @@ sub new_with_options {
     Moose->throw_error('new_with_options is a class method')
         if ! defined $class || blessed($class);
 
+    local @ARGV = MooseX::App::Utils::encoded_argv();
+
     return $class->initialize_command_class($class,%args);
 }
 
